==> rWikiPathways_1.0.5.zip: rWikiPathways/doc/rWikiPathways-and-RCy3.R <==
## ---- echo = FALSE---------------------------------------------------------
knitr::opts_chunk$set(
  eval=FALSE
)

## --------------------------------------------------------------------------
#  if(!"rWikiPathways" %in% installed.packages()){
#      source("https://bioconductor.org/biocLite.R")
#      biocLite("rWikiPathways")
#  }
#  library(rWikiPathways)
#  if(!"RCy3" %in% installed.packages()){
#      source("https://bioconductor.org/biocLite.R")
#      biocLite("RCy3")
#  }
#  library(RCy3)

## --------------------------------------------------------------------------
#  cytoscapePing()

## --------------------------------------------------------------------------
#  installApp('WikiPathways')  #only available in Cytoscape 3.7.0 and above

## --------------------------------------------------------------------------
#  gbm.pathways <- findPathwaysByText('Glioblastoma') # many pathways returned
#  human.filter <- lapply(gbm.pathways, function(x) x$species == "Homo sapiens")
#  human.gbm.pathways <- gbm.pathways[unlist(human.filter)] # just the human BRCA2 pathways

## --------------------------------------------------------------------------
#  human.gbm.wpids <- unique(unlist(lapply(human.gbm.pathways, function(x) x$id)))

## --------------------------------------------------------------------------
#  commandsRun(paste0('wikipathways import-as-pathway id=',human.gbm.wpids[1]))

## --------------------------------------------------------------------------
#  openSession()
#  net.data <- getTableColumns(columns=c('name','degree.layout','COMMON'))
#  max.gene <- net.data[which.max(unlist(net.data['degree.layout'])),]
#  max.gene

## --------------------------------------------------------------------------
#  mcm1.pathways <-unique(findPathwayIdsByXref('YMR043W','En'))
#  commandsRun(paste0('wikipathways import-as-pathway id=', mcm1.pathways[1]))

## --------------------------------------------------------------------------
#  selectNodes('MCM1','name')

==> rWikiPathways_1.2.1.zip: rWikiPathways/doc/rWikiPathways-and-RCy3.R <==
## ---- echo = FALSE---------------------------------------------------------
knitr::opts_chunk$set(
  eval=FALSE
)

## --------------------------------------------------------------------------
#  if(!"rWikiPathways" %in% installed.packages()){
#      if (!requireNamespace("BiocManager", quietly=TRUE))
#          install.packages("BiocManager")
#      BiocManager::install("rWikiPathways")
#  }
#  library(rWikiPathways)
#  if(!"RCy3" %in% installed.packages()){
#      if (!requireNamespace("BiocManager", quietly=TRUE))
#          install.packages("BiocManager")
#      BiocManager::install("RCy3")
#  }
#  library(RCy3)

## --------------------------------------------------------------------------
#  cytoscapePing()

## --------------------------------------------------------------------------
#  gbm.pathways <- findPathwaysByText('Glioblastoma') # many pathways returned
#  human.filter <- lapply(gbm.pathways, function(x) x$species == "Homo sapiens")
#  human.gbm.pathways <- gbm.pathways[unlist(human.filter)] # just the human BRCA2 pathways

## --------------------------------------------------------------------------
#  human.gbm.wpids <- unique(unlist(lapply(human.gbm.pathways, function(x) x$id)))

## --------------------------------------------------------------------------
#  commandsRun(paste0('wikipathways import-as-pathway id=',human.gbm.wpids[1]))

## --------------------------------------------------------------------------
#  openSession()
#  net.data <- getTableColumns(columns=c('name','degree.layout','COMMON'))
#  max.gene <- net.data[which.max(unlist(net.data['degree.layout'])),]
#  max.gene

## --------------------------------------------------------------------------
#  mcm1.pathways <-unique(findPathwayIdsByXref('YMR043W','En'))
#  commandsRun(paste0('wikipathways import-as-pathway id=', mcm1.pathways[1]))

## --------------------------------------------------------------------------
#  selectNodes('MCM1','name')
